==> elasticloadbalancingv2-0.8.1-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/cloudformation/ListenerCertificateResource.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2.cloudformation;
/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listenercertificate.html
 */
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticloadbalancingv2.$Module.class, fqn = "@aws-cdk/aws-elasticloadbalancingv2.cloudformation.ListenerCertificateResource")
public class ListenerCertificateResource extends software.amazon.awscdk.Resource {
    protected ListenerCertificateResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.elasticloadbalancingv2.cloudformation.ListenerCertificateResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ElasticLoadBalancingV2::ListenerCertificate``.
     * @param parent the ``cdk.Construct`` this ``ListenerCertificateResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``ListenerCertificateResource``
     */
    public ListenerCertificateResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.elasticloadbalancingv2.cloudformation.ListenerCertificateResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html
     */
    public static interface CertificateProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
         */
        java.lang.Object getCertificateArn();
        /**
         * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
         */
        void setCertificateArn(final java.lang.String value);
        /**
         * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
         */
        void setCertificateArn(final software.amazon.awscdk.Token value);

        // ==================================================================
        // Builder
        // ==================================================================

        static Builder builder() {
            return new Builder();
        }

        /**
         * A fluent builder class for {@link CertificateProperty}.
         */
        public static final class Builder {
            private Jsii$Pojo instance = new Jsii$Pojo();

            /**
             * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
             */
            public Builder withCertificateArn(final java.lang.String value) {
                this.instance._certificateArn = value;
                return this;
            }
            /**
             * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
             */
            public Builder withCertificateArn(final software.amazon.awscdk.Token value) {
                this.instance._certificateArn = value;
                return this;
            }
            public CertificateProperty build() {
                CertificateProperty result = this.instance;
                this.instance = new Jsii$Pojo();
                return result;
            }
        }

        /**
         * A PoJo (plain-old-java-object) class that implements {@link CertificateProperty}.
         */
        final class Jsii$Pojo implements CertificateProperty {

            /**
             * Constructor used by builders.
             */
            protected Jsii$Pojo() { }


            protected java.lang.Object _certificateArn;

            public java.lang.Object getCertificateArn() {
                return this._certificateArn;
            }
            public void setCertificateArn(final java.lang.String value) {
                this._certificateArn = value;
            }
            public void setCertificateArn(final software.amazon.awscdk.Token value) {
                this._certificateArn = value;
            }
        }

        /**
         * A proxy class which for javascript object literal which adhere to this interface.
         */
        class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticloadbalancingv2.cloudformation.ListenerCertificateResource.CertificateProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }
            /**
             * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
             */
            @javax.annotation.Nullable
            public java.lang.Object getCertificateArn() {
                return this.jsiiGet("certificateArn", java.lang.Object.class);
            }
            /**
             * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
             */
            public void setCertificateArn(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("certificateArn", value);
            }
            /**
             * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
             */
            public void setCertificateArn(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this.jsiiSet("certificateArn", value);
            }
        }
    }
}

==> elasticloadbalancingv2-0.9.1-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/cloudformation/ListenerCertificateResource.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listenercertificate.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.5 (build 845cc48)", date = "2018-09-14T09:14:12.328Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticloadbalancingv2.$Module.class, fqn = "@aws-cdk/aws-elasticloadbalancingv2.cloudformation.ListenerCertificateResource")
public class ListenerCertificateResource extends software.amazon.awscdk.Resource {
    protected ListenerCertificateResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.elasticloadbalancingv2.cloudformation.ListenerCertificateResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ElasticLoadBalancingV2::ListenerCertificate``.
     * @param parent the ``cdk.Construct`` this ``ListenerCertificateResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``ListenerCertificateResource``
     */
    public ListenerCertificateResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.elasticloadbalancingv2.cloudformation.ListenerCertificateResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.elasticloadbalancingv2.ListenerCertificateArn getRef() {
        return this.jsiiGet("ref", software.amazon.awscdk.services.elasticloadbalancingv2.ListenerCertificateArn.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html
     */
    public static interface CertificateProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
         */
        java.lang.Object getCertificateArn();
        /**
         * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
         */
        void setCertificateArn(final java.lang.String value);
        /**
         * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
         */
        void setCertificateArn(final software.amazon.awscdk.CloudFormationToken value);

        /**
         * @return a {@link Builder} of {@link CertificateProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link CertificateProperty}
         */
        final class Builder {
            @javax.annotation.Nullable
            private java.lang.Object _certificateArn;

            /**
             * Sets the value of CertificateArn
             * @param value ``ListenerCertificateResource.CertificateProperty.CertificateArn``
             * @return {@code this}
             */
            public Builder withCertificateArn(@javax.annotation.Nullable final java.lang.String value) {
                this._certificateArn = value;
                return this;
            }
            /**
             * Sets the value of CertificateArn
             * @param value ``ListenerCertificateResource.CertificateProperty.CertificateArn``
             * @return {@code this}
             */
            public Builder withCertificateArn(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                this._certificateArn = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link CertificateProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public CertificateProperty build() {
                return new CertificateProperty() {
                    @javax.annotation.Nullable
                    private java.lang.Object $certificateArn = _certificateArn;

                    @Override
                    public java.lang.Object getCertificateArn() {
                        return this.$certificateArn;
                    }

                    @Override
                    public void setCertificateArn(@javax.annotation.Nullable final java.lang.String value) {
                        this.$certificateArn = value;
                    }

                    @Override
                    public void setCertificateArn(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                        this.$certificateArn = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticloadbalancingv2.cloudformation.ListenerCertificateResource.CertificateProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getCertificateArn() {
                return this.jsiiGet("certificateArn", java.lang.Object.class);
            }

            /**
             * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
             */
            @Override
            public void setCertificateArn(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("certificateArn", value);
            }

            /**
             * ``ListenerCertificateResource.CertificateProperty.CertificateArn``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html#cfn-elasticloadbalancingv2-listener-certificates-certificatearn
             */
            @Override
            public void setCertificateArn(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("certificateArn", value);
            }
        }
    }
}
